@@ -8,16 +8,18 @@
 
 G_BEGIN_DECLS
 
-/* enumerations from "./champlain-view.h" */
-GType champlain_scroll_mode_get_type (void) G_GNUC_CONST;
-#define CHAMPLAIN_TYPE_SCROLL_MODE champlain_scroll_mode_get_type()
-GType champlain_unit_get_type (void) G_GNUC_CONST;
-#define CHAMPLAIN_TYPE_UNIT champlain_unit_get_type()
+/* enumerations from "./champlain-memphis-renderer.h" */
+GType champlain_memphis_rule_type_get_type (void) G_GNUC_CONST;
+#define CHAMPLAIN_TYPE_MEMPHIS_RULE_TYPE champlain_memphis_rule_type_get_type()
 
-/* enumerations from "./champlain-selection-layer.h" */
+/* enumerations from "./champlain-marker-layer.h" */
 GType champlain_selection_mode_get_type (void) G_GNUC_CONST;
 #define CHAMPLAIN_TYPE_SELECTION_MODE champlain_selection_mode_get_type()
 
+/* enumerations from "./champlain-scale.h" */
+GType champlain_unit_get_type (void) G_GNUC_CONST;
+#define CHAMPLAIN_TYPE_UNIT champlain_unit_get_type()
+
 /* enumerations from "./champlain-tile.h" */
 GType champlain_state_get_type (void) G_GNUC_CONST;
 #define CHAMPLAIN_TYPE_STATE champlain_state_get_type()
